//
//  ENBizCardManager.h
//  ENCardScan
//
//  Created by Tong Liu on 6/20/13.
//  Copyright (c) 2013 Evernote. All rights reserved.
//


@class ENCardProcessingRequest;
@class ENCardProcessingResponse;
@protocol ENContactNoteDataSource;


typedef void (^ENBizCardManagerCardProcessingCompletionBlock)(ENCardProcessingResponse *response);

@interface ENBizCardManager : NSObject {
  NSOperationQueue *mCardOperationQueue;
  
  NSString *mServerURL;
  NSString *mLinkedInKey;
  NSString *mLinkedInSecret;
  
  id<ENContactNoteDataSource> mContactNoteDataSource;
  
  NSMutableDictionary *mSocialSearchRequestMap;
  
  CGFloat mSearchTimeOut;
}

+ (ENBizCardManager *)sharedManager;

/**
 * Data source for searching existing Hello notes in clients' database
 */
@property (assign) id<ENContactNoteDataSource> contactNoteDataSource;

/**
 * Clients will read CardScan server url from current bootstrap profile, and
   must set this property prior to adding card requests
 */
@property (copy) NSString *serverURL;

/**
 * To utilize social search feature, clients need to set LinkedIn key and secret
 * before adding cardscan requests
 */
@property (copy) NSString *linkedInKey;
@property (copy) NSString *linkedInSecret;

@property (assign) CGFloat searchTimeOut;

/**
 * Add a card processing request to ENBizCardManager
   If a request doesn't have a uniqueIdentifier of the original note, or doesn't
   contain any images, it will be ignored
 
 * @param request     see @interface ENCardProcessingRequest
 * @param completion  completion block to be invoked when finished processing
 *                    if the request is cancelled during processing or before starting,
 *                    completion block will NOT be invoked
 */
- (void)addRequest:(ENCardProcessingRequest *)request
        completion:(ENBizCardManagerCardProcessingCompletionBlock)completion;

/**
 * Cancel a previous request (e.g. when user clicks Cancel button)
 * @param requestIDString  unique identifier of the request
 */
- (void)cancelRequestWithIDString:(NSString *)requestIDString;


/**
 * Start social search from a cardscan response
 */
- (void) addSocialSearchRequestFromCardProcessingResponse: (ENCardProcessingResponse *)response;

@end
