//
//  ENBusinessCard.h
//  ENCardScan
//
//  Created by Tong Liu on 6/20/13.
//  Copyright (c) 2013 Evernote. All rights reserved.
//

#import <Foundation/Foundation.h>


@interface ENBusinessCard : NSObject {
  NSString *mLanguage;
  NSInteger mCardWidth;
  NSInteger mCardHeight;
  NSArray *mFields;
#if TARGET_OS_IPHONE || TARGET_IPHONE_SIMULATOR
  UIImage *mFrontImage;
  UIImage *mBackImage;
#else
  NSImage *mFrontImage;
  NSImage *mBackImage;
#endif
  NSInteger mRotationByDegrees;
  NSInteger mScore;
  BOOL mHasTitleField;
}

@property (copy) NSString *language;
@property (assign) NSInteger cardWidth;
@property (assign) NSInteger cardHeight;

@property (retain) NSArray *fields;

#if TARGET_OS_IPHONE || TARGET_IPHONE_SIMULATOR
@property (retain) UIImage *frontImage;
@property (retain) UIImage *backImage;
#else
@property (retain) NSImage *frontImage;
@property (retain) NSImage *backImage;
#endif
@property (assign, readonly) NSInteger rotationByDegrees;

#if TARGET_OS_IPHONE || TARGET_IPHONE_SIMULATOR
- (id)initWithLanguage:(NSString *)language
                fields:(NSArray *)fields
            frontImage:(UIImage *)frontImage
             backImage:(UIImage *)backImage;
#else
- (id)initWithLanguage:(NSString *)language
                fields:(NSArray *)fields
            frontImage:(NSImage *)frontImage
             backImage:(NSImage *)backImage;
#endif

/**
 * Convenient methods to get contact info from the card
 * Returns the contact's full name
 */
- (NSString *)fullName;

/**
 * Convenient methods to get contact info from the card
 * Returns the contact's email addresses as NSArray of NSString's
 */
- (NSArray *)emails;

/**
 * Convenient methods to get contact info from the card
 * Returns the contact's phone numbers as NSArray of NSString's
 */
- (NSArray *)phoneNumbers;

/**
 * Merge information from another ENBusinessCard
 * Used to merge information from back side of a card to the front side
 */
- (void)mergeWithCard:(ENBusinessCard *)anotherCard;

/**
 * "Score" of a business card scan result
 * right now, it's simply defined by "name" + "title"
 * Possible values are 0, 1, and 2
 */
@property (assign, nonatomic) NSInteger score;

/**
 * Returns YES if the card has ENBusinessCardField whose type is ENBCFieldTypeTitle
 */
@property (assign, nonatomic) BOOL hasTitleField;

@end
