//
//  ENCardProcessingResponse.h
//  ENCardScan
//
//  Created by Tong Liu on 6/21/13.
//  Copyright (c) 2013 Evernote. All rights reserved.
//

#import <Foundation/Foundation.h>

@class ENHelloContact;
@class ENBusinessCard;
@interface ENCardProcessingResponse : NSObject {
  NSString *mOriginalNoteUUID;
  NSString *mEnmlContent;
  NSArray *mCardImages;
  NSArray *mAvatars;
  
  ENHelloContact *mContact;
  NSString *mContactName;
  NSArray *mContactEmails;
  NSArray *mContactPhones;
  ENBusinessCard *mCard;
  
  BOOL mWillStartLinkedInSearch;
  
  NSDictionary *mImageRotationMap;
  
  NSArray *mErrors;
  
  NSString *mRawResultForFirstCard;
  NSString *mRawResultForSecondCard;
}

@property (copy, readonly) NSString *originalNoteUUID;
@property (copy) NSString *enmlContent;
@property (retain, readonly) NSArray *cardImages;
@property (retain) NSArray *avatars;

/**
 * Expose some contact info directly to clients, so they can grab them and kick off
 * Social Search phase immediately, without having to parse the note content
 *
 */
@property (retain) ENHelloContact *contact;
@property (copy, readonly) NSString *contactName;
@property (retain, readonly) NSArray *contactEmails;
@property (retain, readonly) NSArray *contactPhones;

/**
 * The full ENBusinessCard object after we scan one side or both sides of the card
 */
@property (retain) ENBusinessCard *card;

/**
 * Tell clients that if we will start a LinkedIn search after sending out this response
 * Clients will then mark the note as needed, and start the timer
 * The UI may still show as "Processing...", though we are already displaying a Hello formatted note
 *
 * YES if we can start LinkedIn profile search, NO otherwise
 */
@property (assign) BOOL willStartLinkedInSearch;

/**
 * Tell clients that some of the card images need to be rotated if possible.
 * Our cardscan server will try its best to tell us whether the submitted image
 * is rotated, and if so, will also tell us the degrees (90, 180, or 270 clockwise).
 * We include this information in the response so clients (that manipulate the original
 * resources), can handle them accordingly.
 * 
 * rotationMap key: image hash  value: NSNumber of degrees, can only be 90, 180, or 270
 */
@property (retain) NSDictionary *imageRotationMap;

@property (retain, readonly) NSArray *errors;

/**
 * raw XML result for the first card image
 */
@property (retain) NSString *rawResultForFirstCard;

/**
 * raw XML result for the first card image
 */
@property (retain) NSString *rawResultForSecondCard;

@end
