//
//  ENHelloContact.h
//  ENCardScan
//
//  Created by Tong Liu on 6/26/13.
//  Copyright (c) 2013 Evernote. All rights reserved.
//

#import <Foundation/Foundation.h>

@class ENSocialProfile;
@class ENBusinessCard;
@class ENHelloContactField;
@interface ENHelloContact : NSObject {
  NSString *mFullName;
  NSSet *mEmailFields;
  NSSet *mPhoneFields;
  NSSet *mResources;  // will be deprecated
  NSArray *mResourceHashes;
#if TARGET_OS_IPHONE || TARGET_IPHONE_SIMULATOR
  UIImage *mAvatar;
#else
  NSImage *mAvatar;
#endif
  
  NSSet *mTwitterHandles;
  NSSet *mWeiboHandles;
  
  NSString *mJobTitle;
  NSString *mCompany;
  NSString *mURL;
  NSString *mAddress;
  
  NSString *mLinkedInProfileURL;
  NSString *mFacebookProfileURL;
  
  NSArray *mOrderedEmailFields;
  NSArray *mOrderedPhoneFields;
  NSArray *mOrderedTwitterHandles;
  NSArray *mOrderedWeiboHandles;
  NSString *mProfileImageENURLString;
  NSArray *mCardImageENURLStrings;
}

@property (copy) NSString *fullName;
@property (retain) NSSet *emailFields;
@property (retain) NSSet *phoneFields; // NSSet of ENHelloContactField
#if TARGET_OS_IPHONE || TARGET_IPHONE_SIMULATOR
@property (retain) UIImage *avatar;
#else
@property (retain) NSImage *avatar;
#endif
@property (retain) NSSet *resources;  // will be deprecated
@property (retain) NSArray *resourceHashes;
@property (retain) NSSet *twitterHandles;
@property (retain) NSSet *weiboHandles;
@property (copy) NSString *jobTitle;
@property (copy) NSString *company;
@property (copy) NSString *URL;
@property (copy) NSString *address;
@property (copy) NSString *linkedInProfileURL;
@property (copy) NSString *facebookProfileURL;

// for parsing ENML or HTML content of a contact note
@property (retain) NSArray *orderedEmailFields;     // same order as they appear in ENML
@property (retain) NSArray *orderedPhoneFields;     // same order as they appear in ENML
@property (retain) NSArray *orderedTwitterHandles;
@property (retain) NSArray *orderedWeiboHandles;
@property (retain) NSString *profileImageENURLString;
@property (retain) NSArray *cardImageENURLStrings;  // EvernoteAppURL strings

/**
 * ENHelloContact does not have a designated initializer
 */

/**
 * Initialize with ENBusinessCard
 */
- (id)initWithCard:(ENBusinessCard *)card;

- (void)mergeContactInfoFromContact:(ENHelloContact *)contact;

- (void)mergeContactInfoFromSocialProfile:(ENSocialProfile *)profile
                          avatarIsUpdated:(BOOL *)avatarUpdated;

- (void)saveToContactsWithHelloContact:(ENHelloContact *)contact
                         socialProfile:(ENSocialProfile *)profile
                     completionHandler:(void (^)(BOOL succeeded))completion;

@end


@interface ENHelloContactField : NSObject {
  NSString *mLabel;
  NSString *mText;
}

@property (copy) NSString *label;
@property (copy) NSString *text;

- (id) initWithLabel:(NSString *)label andText:(NSString *)text;

@end
