//
//  ENSystemUtils.h
//  EverNote
//
//  Created by Andrew McGeachie on 7/1/11.
//  Copyright 2011-2012 Evernote. All rights reserved.
//

#import <Cocoa/Cocoa.h>


@interface ENSystemUtils : NSObject {

}


/**
 * Are we running on the specified system or later?
 */
+ (BOOL)runningOnAtLeastMajor:(NSUInteger)major minor:(NSUInteger)minor bugFix:(NSUInteger)bugFix;


/**
 * Are we running on 10.5.x?
 */
+ (BOOL) runningOnLeopard;


/**
 * Are we running on Lion or later?
 */
+ (BOOL) runningOnLionOrLater;


/**
 * Are we running on Lion or later?
 */
+ (BOOL) runningOnMountainLionOrLater;


/**
 * Are we running on Mavericks or later?
 */
+ (BOOL) runningOnMavericksOrLater;


/**
 * Get a set of ProcessSerialNumber objects representing processes whose names match the parameter.
 * @param names Set of names to expect from e.g. CopyProcessName.
 * @return A (possibly empty) set of NSData objects, each of which contains a ProcessSerialNumber.
 */
+ (NSSet *)psnsForProcessesWithNames:(NSSet *)names;


/**
 * Get the bundle path, if any, for the application running with the given PSN.
 */
+ (NSString *)bundlePathForPSN:(ProcessSerialNumber *)psn;


/**
 * Are we using the Mac App-Store for purchases?
 */
+ (BOOL) usingMacAppStore;


/**
 * Get Hardware UUID for XAuth purposes
 */
+ (NSString *) hardwareUUID;

/**
 * Returns if the app is running in a sandbox
 */
+ (BOOL)runningInSandbox;


@end
