//
//  ENSocialProfile.h
//  EvernotePeople
//
//  Created by Alexey Shevchik on 10/5/12.
//  Copyright (c) 2012 Evernote Corporation. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef enum ENSocialProfileType: NSUInteger{
  ENSocialProfileLinkedIn     = 1 << 0,
  ENSocialProfileFacebook     = 1 << 1,
  ENSocialProfileAddressBook  = 1 << 2
} ENSocialProfileType;

@interface ENSocialProfile : NSObject <NSCopying>{
  NSString *_requestID;
  
  NSString *_firstName;
  NSString *_lastName;
  NSString *_formattedName;
  ENSocialProfileType _nameSource;
  
  NSSet *_emailAddresses;
  NSSet *_twitterAccounts;
  NSSet *_phoneNumbers;
  NSSet *_imAccounts;
  
  NSString *_headline;
  ENSocialProfileType _headlineSource;
  NSString *_jobTitle;
  ENSocialProfileType _jobTitleSource;
  NSString *_company;
  ENSocialProfileType _companySource;
  NSString *_location;
  ENSocialProfileType _locationSource;
  NSNumber *_distance;
  NSString *_distanceString;
  
  NSArray *_affiliations;
  NSArray *_educations;
  NSArray *_employers;
  
  NSString *_uidFacebook;
  NSString *_uidLinkedIn;
  NSString *_personIDLinkedIn;
  NSString *_profileURLLinkedInPublic;
  NSString *_profileURLLinkedInSiteStandardRequest;
  NSString *_profileURLFacebook;
  NSString *_avatarURLLinkedIn;
  NSString *_avatarURLFacebookSmall;
  NSString *_avatarURLFacebookBig;
  NSString *_avatarPathLocalFile;
  
  NSString *_uidAddressBook;
  NSArray *_addressList;
  NSString *_additionalNotes;
  NSData *_addressBookAvatarData;
  
  ENSocialProfileType _profileType;
}

@property (nonatomic, copy) NSString *requestID;

@property (nonatomic, copy) NSString * firstName;
@property (nonatomic, copy) NSString * lastName;
@property (nonatomic, copy) NSString * formattedName;
@property (nonatomic, assign) ENSocialProfileType nameSource;

@property (nonatomic, copy) NSSet * emailAddresses;
@property (nonatomic, copy) NSSet * twitterAccounts;
// NSSet of ENPhoneNumber
@property (nonatomic, copy) NSSet * phoneNumbers;
// NSSet of ENIMAccount
@property (nonatomic, copy) NSSet * imAccounts;

@property (nonatomic, copy) NSString * headline;
@property (nonatomic, assign) ENSocialProfileType headlineSource;
@property (nonatomic, copy) NSString * jobTitle;
@property (nonatomic, assign) ENSocialProfileType jobTitleSource;
@property (nonatomic, copy) NSString * company;
@property (nonatomic, assign) ENSocialProfileType companySource;
@property (nonatomic, copy) NSString * location;
@property (nonatomic, assign) ENSocialProfileType locationSource;
@property (nonatomic, copy) NSNumber * distance;
@property (nonatomic, copy) NSString * distanceString;

@property (nonatomic, copy) NSArray * affiliations;
@property (nonatomic, copy) NSArray * educations;
@property (nonatomic, copy) NSArray * employers;

@property (nonatomic, copy) NSString * uidFacebook;
@property (nonatomic, copy) NSString * uidLinkedIn;
@property (nonatomic, copy) NSString * personIDLinkedIn;
@property (nonatomic, copy) NSString * profileURLLinkedInPublic;
// the URL to the member's authenticated profile on LinkedIn (requires a login to be viewed, unlike public profiles)
// from http://developer.linkedin.com/documents/profile-api
@property (nonatomic, copy) NSString * profileURLLinkedInSiteStandardRequest;
@property (nonatomic, copy) NSString * profileURLFacebook;
@property (nonatomic, copy) NSString * avatarURLLinkedIn;
@property (nonatomic, copy) NSString * avatarURLFacebookSmall;
@property (nonatomic, copy) NSString * avatarURLFacebookBig;
@property (nonatomic, copy) NSString * avatarPathLocalFile;

@property (nonatomic, copy) NSString *uidAddressBook;
// NSArray of ENAddress
@property (nonatomic, copy) NSArray * addressList;
@property (nonatomic, copy) NSString * additionalNotes;
@property (nonatomic, retain) NSData * addressBookAvatarData;

@property (readwrite) ENSocialProfileType profileType;

+ (NSArray *) arrayOfPersonWithLinkedInPeopleSearch:(NSDictionary *)peopleSearchDictionary;
+ (id) personWithLinkedInDictionary:(id)linkedInDictionary;
+ (id) personWithFaceBookAffiliationsDictionary:(NSDictionary *)faceBookDictionary;
+ (id) personWithAddressBookProfile: (id)addressBookProfile;
+ (id) personWithParsedContactInfo:(id)contactInfoDictionary;

+(NSString *)compositeLinkedInIdFromPersonId:(NSString*)personId headerName:(NSString*)headerName headerValue:(NSString*)headerValue distance:(NSNumber*)distance;
+(NSString *)personIdFromLinkedInId:(NSString*)linkedInId;
+(NSString *)headerNameFromLinkedInId:(NSString*)linkedInId;
+(NSString *)headerValueFromLinkedInId:(NSString*)linkedInId;
+(NSNumber *)distanceValueFromLinkedInId:(NSString*)linkedInId;

- (NSString*)shortDescription;
- (NSString*)description;
- (void)mergeWithEmailSet:(NSSet *)emailSet;
- (void)mergeWithTwitterSet: (NSSet *)twitterSet;
- (void)mergeWithPhoneNumberSet: (NSSet *)phoneSet;

@end

@interface ENPhoneNumber : NSObject {
  NSString *_number;
  NSString *_type;
}

@property (copy) NSString* number;
@property (copy) NSString* type;

+ (NSString *)plainPhoneNumberForPhoneNumberString:(NSString *)phoneNumberString;
+ (ENPhoneNumber *)phoneNumberWithNumber:(NSString *)aNumber type:(NSString *)phoneType;
- (NSString *)description;

@end

@interface ENAffiliation : NSObject {
  NSNumber *_nid;
  NSString *_type;
  NSString *_name;
}

@property (copy) NSNumber * nid;
@property (copy) NSString * type;
@property (copy) NSString * name;

+ (NSArray *) affiliationsWithArray:(NSArray *)arrayOfAffiliations;
+ (id) affilationWithDictionary:(NSDictionary *)aDictionary;
- (NSString *)description;

@end

@interface ENEmployer : NSObject {
  NSNumber *_nid;
  NSString *_name;
}

@property (copy) NSNumber * nid;
@property (copy) NSString * name;

+ (NSArray *)employersWithArray:(NSArray *)arrayOfEmployers;
+ (ENEmployer *)employerWithDictionary:(NSDictionary *)aDictionary;
- (NSString *)description;

@end

@interface ENEducation : NSObject {
  NSNumber *_nid;
  NSArray *_concentrations;
  NSString *_schoolName;
  NSString *_schoolType;
}

@property (copy) NSNumber * nid;
// NSArray of NSString
@property (copy) NSArray * concentrations;
@property (copy) NSString * schoolName;
@property (copy) NSString * schoolType;

+ (NSArray *)educationsWithArray:(NSArray *)arrayOfEducations;
- (NSString *)concentrationsDescription;
- (NSString *)description;

@end

@interface ENIMAccount : NSObject {
  NSString *_userName;
  NSString *_label;
  NSString *_type;
}

@property (copy) NSString * userName;
@property (copy) NSString * label;
@property (copy) NSString * type;

+ (ENIMAccount *)imAccountWithUserName:(NSString *)userName label:(NSString *)label type:(NSString *)type;
- (NSString *)description;

@end

// addressDictionary keys
extern NSString * const kENAddressStreetKey;
extern NSString * const kENAddressCityKey;
extern NSString * const kENAddressStateKey;
extern NSString * const kENAddressZIPKey;
extern NSString * const kENAddressCountryKey;
extern NSString * const kENAddressCountryCodeKey;
@interface ENAddress : NSObject {
  NSString *_label;
  NSDictionary *_addressDictionary;
  NSString *_formattedAddress;
}

@property (copy) NSString *label;
@property (copy) NSDictionary *addressDictionary;
@property (copy) NSString *formattedAddress;

+ (ENAddress *)addressWithLabel:(NSString *)label detailsDictionary:(NSDictionary *)detailsDictionary;
- (NSString *)description;

@end

@interface ENEmail : NSObject {
  NSString *_label;
  NSString *_address;
}

@property (copy) NSString *label;
@property (copy) NSString *address;

+ (ENEmail *)emailWithLabel:(NSString *)label address:(NSString *)address;
- (NSString *)description;

@end
