//
//  ENSocialSearchManager.h
//  SocialSearch
//
//  Created by Eric Cheng on 7/16/13.
//  Copyright (c) 2013 Evernote Corp. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ENSocialSearchMerger.h"

@class ENContact;
@protocol ENContactNoteSearchingDataSource <NSObject>

@required;

/**
 * Provide data source fullName, email addresses, and phone numbers, and get a
 * ENContact object matching the info
 * @param fullName     full name of the contact, provided as is, case insensitive
 * @param emails       0 or more email addresses, you should put the more important ones at the front
 * @param phoneNumbers 0 or more phone numbers, you should put the more important ones at the front
 */
- (ENContact *) contactMatchingName:(NSString *)fullName
                             emails:(NSArray *)emails
                       phoneNumbers:(NSArray *)phoneNumbers;

@end


@class ENSocialSearchResponse;
@class ENSocialSearchRequest;

typedef void (^SocialSearchCompletionBlock)(ENSocialSearchResponse *response);

@interface ENSocialSearchManager : NSObject {
  NSOperationQueue *_searchOperationQueue;
  NSMutableDictionary *_socialProfileMaps;
  NSString *_facebookAccessToken;
  BOOL linkedinEnabled;
  BOOL facebookEnabled;
  BOOL addressBookEnabled;
  SocialSearchMergeOptionType _mergeOption;
  
  id<ENContactNoteSearchingDataSource> mContactDataSource;
  id<NSObject> mLinkedInEngineDelegate;
}

@property (retain, nonatomic) NSOperationQueue *searchOperationQueue;
@property (retain) NSMutableDictionary *socialProfileMaps;
@property (readonly, nonatomic) BOOL linkedInEnabled;
@property (readonly, nonatomic) BOOL facebookEnabled;
@property (readonly, nonatomic) BOOL addressBookEnabled;
@property (assign) SocialSearchMergeOptionType mergeOption;

/**
 * Data source that will search for existing Hello Contacts given combination of inputs
 */
@property (assign) id<ENContactNoteSearchingDataSource> contactDataSource;

/**
 * Clients can set this property so ENLinkedInController know where to get the cached access token & key
 */
@property (assign) id<NSObject> linkedInEngineDelegate;

+(ENSocialSearchManager *)sharedManager;

- (void)loginFacebookWithCompletion:(void (^)(BOOL succeeded))completion;
- (void)logoutFacebook;
- (void)setFacebookAccessToken:(NSString*) accessToken expires: (NSTimeInterval) tokenExpires permissions: (NSString*) perms error: (NSString*) errorReason;

- (void)loginLinkedInWithCompletion:(void (^)(BOOL succeeded))completion;
- (void)logoutLinkedIn;
- (void)setLinkedInExternalKey:(NSString*)externalKey externalSecret:(NSString*)externalSecret;

- (BOOL)addSearchByRequest:(ENSocialSearchRequest *)request completion:(SocialSearchCompletionBlock)completion;
- (void)saveSocialProfileInAddressBook: (ENSocialProfile *)profile completionHandler:(void (^)(BOOL))completion;

@end
