//
//  GAMTracker.h
//  GAMKit
//
//  Created by Isaac Wankerl on 11/12/13.
//  Copyright (c) 2013 Evernote Corp. All rights reserved.
//

#import <Foundation/Foundation.h>

@protocol GAMTracker<NSObject>

/*!
 Name of this tracker.
 */
@property(nonatomic, readonly) NSString *name;

/*!
 Set a tracking parameter.

 @param parameterName The parameter name.

 @param value The value to set for the parameter. If this is nil, the
 value for the parameter will be cleared.
 */
- (void)set:(NSString *)parameterName value:(NSString *)value;

/*!
 Get a tracking parameter.

 @param parameterName The parameter name.

 @returns The parameter value, or nil if no value for the given parameter is
 set.
 */
- (NSString *)get:(NSString *)parameterName;

/*!
 Queue tracking information with the given parameter values.

 @param parameters A map from parameter names to parameter values which will be
 set just for this piece of tracking information, or nil for none.
 */
- (void)send:(NSDictionary *)parameters;




/*!
 Queue an event hit

 @param category A map from parameter names to parameter values which will be
 @param action   A map from parameter names to parameter values which will be
 @param label    A map from parameter names to parameter values which will be
 @param value    A map from parameter names to parameter values which will be
 */
- (void)sendEventWithCategory:(NSString *)category action:(NSString *)action label:(NSString *)label value:(NSNumber *)value;

/*!
 Queue a pageview

 @param pageName The name of the page/screen
 */
- (void)sendPageViewWithPage:(NSString *)pageName;

@end
